#!/bin/sh
#------------------------------------------------------------------------------
# /var/install/config.d/unison-update.sh - parameter update script
#
# Copyright (c) 2004 Daniel Vogel <daniel_vogel(at)t-online(dot)de>
#
# Creation:     03.07.2005 dv
# Last Update:  $Id: unison-update.sh 2 2017-10-18 18:52:17Z  $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------
packages_name=unison

. /var/install/include/eislib
. /var/install/include/configlib

START_UNISON='no'                        # Shall unison deamon be started
UNISON_DAEMON_PORT='3000'                # Port used for socket daemon
UNISON_DAEMON_INTERFACE=''               # Interface or hostname to bind
                                         # socket to
UNISON_DAEMON_UMASK='022'                # umask to apply for socket daemon

UNISON_MAIL_NOTIFY='no'                  # Use mail notification
UNISON_MAIL_ONERROR='no'                 # Notify errors only
UNISON_MAIL_ADDR='root@localhost'        # Mail address to send reports to

UNISON_DIR_N='0'                         # Number of directories

UNISON_DIR_1_NETSYNC='no'                # Network sync  
UNISON_DIR_1_HOST='mirror.local.lan'     # Remote host (if any)
UNISON_DIR_1_USESSH='no'                 # Use SSH transfer
UNISON_DIR_1_SSHPORT='22'                # SSH port number to connect to
UNISON_DIR_1_SSHUSER='unison'            # SSH user for remote login
UNISON_DIR_1_SSHCOMPRESS='no'            # SSH compression
UNISON_DIR_1_USESOCKET='no'              # Access method to use
UNISON_DIR_1_SOCKPORT='3000'             # Socket daemon port (if used)

UNISON_DIR_1_LOCAL='/home'               # Local data directory
UNISON_DIR_1_REMOTE='/backup'            # Remote data directory
UNISON_DIR_1_FORCE='none'                # 'none', 'local', 'remote'
UNISON_DIR_1_TIMES='no'                  # Synchronize file times
UNISON_DIR_1_OWNER='no'                  # Synchronize file owner
UNISON_DIR_1_GROUP='no'                  # Synchronize file group
UNISON_DIR_1_NUMIDS='no'                 # Numeric id's for user and group
UNISON_DIR_1_FAT='no'                    # Replicate with a FAT filesystem

UNISON_DIR_1_PATH_N='0'                  # Subdirectories that shall be synch.
UNISON_DIR_1_PATH_1='administration'     # Subdirectory to synchronize
UNISON_DIR_1_PATH_2='production'         # Subdirectory to synchronize
UNISON_DIR_1_PATH_3='development'        # Subdirectory to synchronize

UNISON_DIR_1_EXC_FILE_N='0'              # Number of file patterns to exclude
UNISON_DIR_1_EXC_FILE_1='*~'             # File pattern to exclude
UNISON_DIR_1_EXC_FILE_2='*.bak'          # File pattern to exclude

UNISON_DIR_1_EXC_PATH_N='0'              # Number of path patterns to exclude
UNISON_DIR_1_EXC_PATH_1='*/pictures'     # Path pattern to exclude
UNISON_DIR_1_EXC_PATH_2='*/tmp'          # Path pattern to exclude

UNISON_DIR_1_INC_FILE_N='0'              # Number of file patterns to reinclude
UNISON_DIR_1_INC_FILE_1='*.jpg'          # File pattern to reinclude
UNISON_DIR_1_INC_FILE_2='*.htm'          # File pattern to reinclude

UNISON_DIR_1_AUTO='yes'                  # Automatic synchronisation
UNISON_DIR_1_SCHEDULE='0 1 * * *'        # Crontab entry for execution

UNISON_DIR_1_PRERUN=''                   # Command executed before sync
UNISON_DIR_1_POSTRUN=''                  # Command executed after sync


# -----------------------------------------------------------------------------
# rename old variables
# -----------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${packages_name} ]
    then
        # first of all, all sensible options have to
        # be initialized, so that we can detect old
        # config values and translate them correctly
        UNISON_DIR_1_NETSYNC=""
        UNISON_DIR_1_HOST=""
        UNISON_DIR_1_USESSH=""
        UNISON_DIR_1_USESOCKET=""

        # now read the old configuration file
        . /etc/config.d/${packages_name}

        # now rename and convert
        if [ "$START_UNISON_DAEMON" != "" ]
        then       
            START_UNISON="$START_UNISON_DAEMON"
        fi

        if [ "$UNISON_AUTORUN_MAILADDR" != "" ]
        then
            UNISON_MAIL_NOTIFY='yes'
            UNISON_MAIL_ONERROR='no'
            UNISON_MAIL_ADDR="$UNISON_AUTORUN_MAILADDR"
        fi

        if [ "$UNISON_DIR_N" == "0" ]
        then
            UNISON_DIR_1_NETSYNC="no"
            UNISON_DIR_1_HOST="mirror.local.lan"
            UNISON_DIR_1_USESSH="no"
            UNISON_DIR_1_USESOCKET="no"
        else
            idx=1
            while [ "$idx" -le "$UNISON_DIR_N" ]
            do
                eval netsync='$UNISON_DIR_'$idx'_NETSYNC'
                eval host='$UNISON_DIR_'$idx'_HOST'
                eval method='$UNISON_DIR_'$idx'_METHOD'
                eval usessh='$UNISON_DIR_'$idx'_USESSH'
                eval sshport='$UNISON_DIR_'$idx'_SSHPORT'

                if [ "$netsync" == "" ]
                then
                    if [ "$host" == "" ]
                    then
                        eval UNISON_DIR_${idx}_NETSYNC="no"
                        eval UNISON_DIR_${idx}_HOST="mirror.local.lan"
                        eval UNISON_DIR_${idx}_USESSH="no"
                        eval UNISON_DIR_${idx}_USESOCKET="no"
                    else
                        eval UNISON_DIR_${idx}_NETSYNC="yes"
                        if [ "$usessh" == "" ]
                        then
                            if [ "$method" == "ssh" ]
                            then
                                eval UNISON_DIR_${idx}_USESSH="yes"
                                eval UNISON_DIR_${idx}_USESOCKET="no"
                            else
                                eval UNISON_DIR_${idx}_USESSH="no"
                                eval UNISON_DIR_${idx}_USESOCKET="yes"
                            fi
                        fi
                    fi
                fi
                idx=$[$idx + 1]
            done
        fi
    fi
}


# -----------------------------------------------------------------------------
# add new variables
# -----------------------------------------------------------------------------
add_new_variables()
{
    idx=1
    while [ "$idx" -le "$UNISON_DIR_N" ]
    do
        eval force='$UNISON_DIR_'$idx'_FORCE'
        if [ "$force" == "" ]
        then
            echo "new: UNISON_DIR_${idx}_FORCE"
            eval UNISON_DIR_${idx}_FORCE="none"
        fi
        idx=`/usr/bin/expr $idx + 1`
    done

    idx=1
    while [ "$idx" -le "$UNISON_DIR_N" ]
    do
        eval fatopt='$UNISON_DIR_'$idx'_FAT'
        if [ "$fatopt" == "" ]
        then
            echo "new: UNISON_DIR_${idx}_FAT"
            eval UNISON_DIR_${idx}_FAT="no"
        fi
        idx=`/usr/bin/expr $idx + 1`
    done

    idx=1
    while [ "$idx" -le "$UNISON_DIR_N" ]
    do
        eval numpaths='$UNISON_DIR_'$idx'_PATH_N'
        if [ "$numpaths" == "" ]
        then
            echo "new: UNISON_DIR_${idx}_PATH_N"
            eval UNISON_DIR_${idx}_PATH_N="0"
        fi
        idx=`/usr/bin/expr $idx + 1`
    done

    idx=1
    while [ "$idx" -le "$UNISON_DIR_N" ]
    do
        eval numfiles='$UNISON_DIR_'$idx'_INC_FILE_N'
        if [ "$numfiles" == "" ]
        then
            echo "new: UNISON_DIR_${idx}_INC_FILE_N"
            eval UNISON_DIR_${idx}_INC_FILE_N="0"
        fi
        idx=`/usr/bin/expr $idx + 1`
    done

    idx=1
    while [ "$idx" -le "$UNISON_DIR_N" ]
    do
        eval ids='$UNISON_DIR_'$idx'_TIMES'
        if [ "$ids" == "" ]
        then
            echo "new: UNISON_DIR_${idx}_TIMES"
            eval UNISON_DIR_${idx}_TIMES="no"
        fi
        eval owner='$UNISON_DIR_'$idx'_OWNER'
        if [ "$owner" == "" ]
        then
            echo "new: UNISON_DIR_${idx}_OWNER"
            eval UNISON_DIR_${idx}_OWNER="no"
        fi
        eval group='$UNISON_DIR_'$idx'_GROUP'
        if [ "$group" == "" ]
        then
            echo "new: UNISON_DIR_${idx}_GROUP"
            eval UNISON_DIR_${idx}_GROUP="no"
        fi
        eval ids='$UNISON_DIR_'$idx'_NUMIDS'
        if [ "$ids" == "" ]
        then
            echo "new: UNISON_DIR_${idx}_NUMIDS"
            eval UNISON_DIR_${idx}_NUMIDS="no"
        fi

        idx=`/usr/bin/expr $idx + 1`
    done

    idx=1
    while [ "$idx" -le "$UNISON_DIR_N" ]
    do
        eval sshport='$UNISON_DIR_'$idx'_SSHPORT'
        if [ "$sshport" == "" ]
        then
            echo "new: UNISON_DIR_${idx}_SSHPORT"
            eval UNISON_DIR_${idx}_SSHPORT="22"
        fi

        eval sshcompress='$UNISON_DIR_'$idx'_SSHCOMPRESS'
        if [ "$sshcompress" == "" ]
        then
            echo "new: UNISON_DIR_${idx}_SSHCOMPRESS"
            eval UNISON_DIR_${idx}_SSHCOMPRESS="no"
        fi

        idx=`/usr/bin/expr $idx + 1`
    done
}

# -----------------------------------------------------------------------------
# write config files
# -----------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=$1
    (
    printgpl -conf "$packages_name" "2008-08-03" "dv" \
         "2008 Daniel Vogel, daniel_vogel(at)t-online(dot)de"

    printgroup "Unison server settings"
    printvar "START_UNISON" "Shall unison deamon be started"
    printvar "UNISON_DAEMON_PORT" "Port used for socket daemon"
    printvar "UNISON_DAEMON_INTERFACE" "Interface or hostname to bind socket to"
    printvar "UNISON_DAEMON_UMASK" "umask to apply for socket daemon"

    printgroup "Unison mail notification"
    printvar "UNISON_MAIL_NOTIFY" "Use mail notification"
    printvar "UNISON_MAIL_ONERROR" "Notify errors only"
    printvar "UNISON_MAIL_ADDR" "Mail address to send reports to"

    printgroup "Unison synchronisation directories"
    printvar "UNISON_DIR_N" "Number of directories"

    printgroup "Replica %i" 
    echo "#  Network options for replica %i"
    echo ""
    printvar "UNISON_DIR_1_NETSYNC" "Network sync"
    printvar "UNISON_DIR_1_HOST" "Remote host (if any)"
    printvar "UNISON_DIR_1_USESSH" "Use SSH transfer"
    printvar "UNISON_DIR_1_SSHPORT" "SSH port number to connect to"
    printvar "UNISON_DIR_1_SSHUSER" "SSH user for remote login"
    printvar "UNISON_DIR_1_SSHCOMPRESS" "SSH data compression"
    printvar "UNISON_DIR_1_USESOCKET" "Use socket daemon transfer"
    printvar "UNISON_DIR_1_SOCKPORT" "Socket daemon port"
    echo ""
    echo "#  Sync options for replica %i"
    echo ""
    printvar "UNISON_DIR_1_LOCAL" "Local root directory"
    printvar "UNISON_DIR_1_REMOTE" "Remote root directory"
    printvar "UNISON_DIR_1_FORCE" "Force 'local' or 'remote'"
    printvar "UNISON_DIR_1_TIMES" "Synchronize file times"
    printvar "UNISON_DIR_1_OWNER" "Synchronize file owner"
    printvar "UNISON_DIR_1_GROUP" "Synchronize file group"
    printvar "UNISON_DIR_1_NUMIDS" "Numeric id's for user and group"
    printvar "UNISON_DIR_1_FAT" "Replicate with a FAT file system"
    echo ""
    echo "#  Subdirectories of replica %i"
    echo ""
    printvar "UNISON_DIR_1_PATH_N" "Subdirectories to synchronize"
    printvar "UNISON_DIR_1_PATH_1" "Subdirectory to synchronize"
    printvar "UNISON_DIR_1_PATH_2" "Subdirectory to synchronize"
    printvar "UNISON_DIR_1_PATH_3" "Subdirectory to synchronize"
    iidx=4
    while [ "$iidx" -le "$UNISON_DIR_1_PATH_N" ]
    do
        printvar "UNISON_DIR_1_PATH_${iidx}" "Subdirectory to synchronize"
        iidx=`/usr/bin/expr $iidx + 1`
    done
    echo ""
    echo "#  File inclusion and exclusion of replica %i"
    echo ""
    printvar "UNISON_DIR_1_EXC_FILE_N" "Number of file patterns to exclude"
    printvar "UNISON_DIR_1_EXC_FILE_1" "File pattern to exclude"
    printvar "UNISON_DIR_1_EXC_FILE_2" "File pattern to exclude"
    iidx=3
    while [ "$iidx" -le "$UNISON_DIR_1_EXC_FILE_N" ]
    do
        printvar "UNISON_DIR_1_EXC_FILE_${iidx}" "File pattern to exclude"
        iidx=`/usr/bin/expr $iidx + 1`
    done
    echo ""
    printvar "UNISON_DIR_1_EXC_PATH_N" "Number of path patterns to exclude"
    printvar "UNISON_DIR_1_EXC_PATH_1" "Path pattern to exclude"
    printvar "UNISON_DIR_1_EXC_PATH_2" "Path pattern to exclude"
    iidx=3
    while [ "$iidx" -le "$UNISON_DIR_1_EXC_PATH_N" ]
    do
        printvar "UNISON_DIR_1_EXC_PATH_${iidx}" "Path pattern to exclude"
        iidx=`/usr/bin/expr $iidx + 1`
    done
    echo ""
    printvar "UNISON_DIR_1_INC_FILE_N" "Number of file patterns to reinclude"
    printvar "UNISON_DIR_1_INC_FILE_1" "File pattern to reinclude"
    printvar "UNISON_DIR_1_INC_FILE_2" "File pattern to reinclude"
    iidx=3
    while [ "$iidx" -le "$UNISON_DIR_1_INC_FILE_N" ]
    do
        printvar "UNISON_DIR_1_INC_FILE_${iidx}" "File pattern to reinclude"
        iidx=`/usr/bin/expr $iidx + 1`
    done

    echo ""
    echo "#  Automatic synchronisation of replica %i"
    echo ""
    printvar "UNISON_DIR_1_AUTO" "Automatic synchronisation"
    printvar "UNISON_DIR_1_SCHEDULE" "Crontab entry for execution"
    printvar "UNISON_DIR_1_PRERUN" "Command executed before sync"
    printvar "UNISON_DIR_1_POSTRUN" "Command executed after symc"

    idx=2
    while [ "$idx" -le "$UNISON_DIR_N" ]
    do
        printgroup "Replica %i"
        echo "#  Network options for replica %i"
        echo ""
        printvar "UNISON_DIR_${idx}_NETSYNC" "Network sync"
        printvar "UNISON_DIR_${idx}_HOST" "Remote host (if any)"
        printvar "UNISON_DIR_${idx}_USESSH" "Use SSH transfer"
        printvar "UNISON_DIR_${idx}_SSHPORT" "SSH port number to connect to"
        printvar "UNISON_DIR_${idx}_SSHUSER" "SSH user for remote login"
        printvar "UNISON_DIR_${idx}_SSHCOMPRESS" "SSH data compression"
        printvar "UNISON_DIR_${idx}_USESOCKET" "Use socket daemon transfer"
        printvar "UNISON_DIR_${idx}_SOCKPORT" "Socket daemon port"
        echo ""
        echo "#  Sync options for replica %i"
        echo ""
        printvar "UNISON_DIR_${idx}_LOCAL" "Local root directory"
        printvar "UNISON_DIR_${idx}_REMOTE" "Remote root directory"
        printvar "UNISON_DIR_${idx}_FORCE" "Force 'local' or 'remote'"
        printvar "UNISON_DIR_${idx}_TIMES" "Synchronize file times"
        printvar "UNISON_DIR_${idx}_OWNER" "Synchronize file owner"
        printvar "UNISON_DIR_${idx}_GROUP" "Synchronize file group"
        printvar "UNISON_DIR_${idx}_NUMIDS" "Numeric id's for user and group"
        printvar "UNISON_DIR_${idx}_FAT" "Replicate with a FAT file system"
        echo ""
        echo "#  Subdirectories of replica %i"
        echo ""
        iidx=1
        eval numpaths='$UNISON_DIR_'$idx'_PATH_N'
        printvar "UNISON_DIR_${idx}_PATH_N" "Subdirectories to synchronize"
        if [ "$iidx" -le "$numpaths" ]
        then
           while [ "$iidx" -le "$numpaths" ]
           do
               printvar "UNISON_DIR_${idx}_PATH_${iidx}" "Subdirectory to synchronize"
               iidx=`/usr/bin/expr $iidx + 1`
           done
        fi
        echo ""
        echo "#  File inclusion and exclusion of replica %i"
        echo ""
        iidx=1
        eval numfiles='$UNISON_DIR_'$idx'_EXC_FILE_N'
        printvar "UNISON_DIR_${idx}_EXC_FILE_N" "Number of file patterns to exclude"
        if [ "$iidx" -le "$numfiles" ]
        then
           while [ "$iidx" -le "$numfiles" ]
           do
               printvar "UNISON_DIR_${idx}_EXC_FILE_${iidx}" "File pattern to exclude"
               iidx=`/usr/bin/expr $iidx + 1`
           done
        fi
        echo ""
        iidx=1
        eval numpaths='$UNISON_DIR_'$idx'_EXC_PATH_N'
        printvar "UNISON_DIR_${idx}_EXC_PATH_N" "Number of path patterns to exclude"
        if [ "$iidx" -le "$numpaths" ]
        then
            while [ "$iidx" -le "$numpaths" ]
            do
                printvar "UNISON_DIR_${idx}_EXC_PATH_${iidx}" "Path pattern to exclude"
                iidx=`/usr/bin/expr $iidx + 1`
            done
        fi
        echo ""
        iidx=1
        eval numfiles='$UNISON_DIR_'$idx'_INC_FILE_N'
        printvar "UNISON_DIR_${idx}_INC_FILE_N" "Number of file patterns to reinclude"
        if [ "$iidx" -le "$numfiles" ]
        then
           while [ "$iidx" -le "$numfiles" ]
           do
               printvar "UNISON_DIR_${idx}_INC_FILE_${iidx}" "File pattern to reinclude"
               iidx=`/usr/bin/expr $iidx + 1`
           done
        fi
        echo ""
        echo "#  Automatic synchronisation of replica %i"
        echo ""
        printvar "UNISON_DIR_${idx}_AUTO" "Automatic synchronisation"
        printvar "UNISON_DIR_${idx}_SCHEDULE" "Crontab entry for execution"
        printvar "UNISON_DIR_${idx}_PRERUN" "Command executed before sync"
        printvar "UNISON_DIR_${idx}_POSTRUN" "Command executed after sync"

        idx=`/usr/bin/expr $idx + 1`
    done

    printend
    ) > $internal_conf_file

    # Set rights
    chmod 0644 $internal_conf_file
    chown root $internal_conf_file
}

# -----------------------------------------------------------------------------
# Create the check.d file
# -----------------------------------------------------------------------------
make_check_file()
{
    (
    printgpl -check "$packages_name" "2008-08-03" "dv" \
         "2008 Daniel Vogel, daniel_vogel(at)t-online(dot)de"

    echo "# Variable                 OPT_VARIABLE           VARIABLE_N         VALUE"
    echo "START_UNISON               -                      -                  YESNO"
    echo "UNISON_DAEMON_PORT         START_UNISON           -                  NUMERIC"
    echo "UNISON_DAEMON_INTERFACE    START_UNISON           -                  NONE"
    echo "UNISON_DAEMON_UMASK        START_UNISON           -                  UNISONUMASK"
    echo "UNISON_MAIL_NOTIFY         -                      -                  YESNO"
    echo "UNISON_MAIL_ONERROR        UNISON_MAIL_NOTIFY     -                  YESNO"
    echo "UNISON_MAIL_ADDR           UNISON_MAIL_NOTIFY     -                  MAILADDR"
    echo "UNISON_DIR_N               -                      -                  NUMERIC"
    echo "UNISON_DIR_%_NETSYNC       -                      UNISON_DIR_N       YESNO"
    echo "UNISON_DIR_%_HOST          UNISON_DIR_%_NETSYNC   UNISON_DIR_N       FQDN"
    echo "UNISON_DIR_%_USESSH        UNISON_DIR_%_NETSYNC   UNISON_DIR_N       YESNO"
    echo "UNISON_DIR_%_SSHPORT       UNISON_DIR_%_USESSH    UNISON_DIR_N       NUMERIC"
    echo "UNISON_DIR_%_SSHUSER       UNISON_DIR_%_USESSH    UNISON_DIR_N       NOTEMPTY"
    echo "UNISON_DIR_%_SSHCOMPRESS   UNISON_DIR_%_USESSH    UNISON_DIR_N       YESNO"
    echo "UNISON_DIR_%_USESOCKET     UNISON_DIR_%_NETSYNC   UNISON_DIR_N       YESNO"
    echo "UNISON_DIR_%_SOCKPORT      UNISON_DIR_%_USESOCKET UNISON_DIR_N       NUMERIC"
    echo "UNISON_DIR_%_LOCAL         -                      UNISON_DIR_N       ABS_PATH"
    echo "UNISON_DIR_%_REMOTE        -                      UNISON_DIR_N       UNISONABSPATH"
    echo "UNISON_DIR_%_FORCE         -                      UNISON_DIR_N       UNISONFORCE"
    echo "UNISON_DIR_%_TIMES         -                      UNISON_DIR_N       YESNO"
    echo "UNISON_DIR_%_OWNER         -                      UNISON_DIR_N       YESNO"
    echo "UNISON_DIR_%_GROUP         -                      UNISON_DIR_N       YESNO"
    echo "UNISON_DIR_%_NUMIDS        -                      UNISON_DIR_N       YESNO"
    echo "UNISON_DIR_%_FAT           -                      UNISON_DIR_N       YESNO"
    echo "UNISON_DIR_%_PATH_N        -                      UNISON_DIR_N       NUMERIC"
    echo "UNISON_DIR_%_PATH_%        -                      UNISON_DIR_%_PATH_N  REL_PATH"
    echo "UNISON_DIR_%_EXC_FILE_N    -                      UNISON_DIR_N       NUMERIC"
    echo "UNISON_DIR_%_EXC_FILE_%    -                      UNISON_DIR_%_EXC_FILE_N  UNISONFILE"
    echo "UNISON_DIR_%_EXC_PATH_N    -                      UNISON_DIR_N       NUMERIC"
    echo "UNISON_DIR_%_EXC_PATH_%    -                      UNISON_DIR_%_EXC_PATH_N  UNISONPATH"
    echo "UNISON_DIR_%_INC_FILE_N    -                      UNISON_DIR_N       NUMERIC"
    echo "UNISON_DIR_%_INC_FILE_%    -                      UNISON_DIR_%_INC_FILE_N  UNISONFILE"
    echo "UNISON_DIR_%_AUTO          -                      UNISON_DIR_N       YESNO"
    echo "UNISON_DIR_%_SCHEDULE      UNISON_DIR_%_AUTO      UNISON_DIR_N       CRONTAB"
    echo "UNISON_DIR_%_PRERUN        -                      UNISON_DIR_N       NONE"
    echo "UNISON_DIR_%_POSTRUN       -                      UNISON_DIR_N       NONE"
    echo ""
    ) > /etc/check.d/$packages_name

    # Set rights for check.d file
    chmod 0644 /etc/check.d/$packages_name
    chown root /etc/check.d/$packages_name

    (
    printgpl -check_exp "$packages_name" "2008-08-03" "dv" \
         "2008 Daniel Vogel, daniel_vogel(at)t-online(dot)de"

    echo "UNISONFORCE            = 'none|local|remote'"
    echo "                       : 'only \"none\", \"local\" and \"remote\" are allowed'"
    echo "UNISONSET              = '\[(([[:alnum:]]|[-_.])+)\]'"
    echo "                       : 'invalid set of characters'"
    echo "UNISONPAT              = '\{(([[:alnum:]]|[-_.,])+)\}'"
    echo "                       : 'invalid pattern of characters'"
    echo "UNISONPATH             = '(([[:alnum:]]|[-_.*?]|(RE:UNISONSET)|(RE:UNISONPAT))+)(/([[:alnum:]]|[-_.*?]|(RE:UNISONSET)|(RE:UNISONPAT))+)*/?'"
    echo "                       : 'no valid path pattern, only numbers, letters, \"-\" , \"_\", \"?\""
    echo "                          and \"*\" divided by \"/\" are allowed. Further you can specify sets like [abc]"
    echo "                          or patterns like {a,bb,ccc}'"
    echo "UNISONFILE             = '([[:alnum:]]|[-_.*?~]|(RE:UNISONSET)|(RE:UNISONPAT))+'"
    echo "                       : 'no valid path pattern, only numbers, letters, \"-\" , \"_\", \"?\""
    echo "                          and \"*\" are allowed. Further you can specify sets like [abc]"
    echo "                          or patterns like {a,bb,ccc}'"
    echo "UNISONDOSPATH          = '(([[:alnum:]]|[-_. ])+)(\\\\([[:alnum:]]|[-_. ])+)*/?'"
    echo "                       : 'no valid relative path, only numbers, letters, "-" and"
    echo "                          \"_\" divided by \"\\\" are allowed'"
    echo "UNISONABSPATH          = '(RE:ABS_PATH)|(([A-Z]|[a-z]):\\\\(RE:UNISONDOSPATH)?)'"
    echo "                       : 'no valid absolute path (may be either an absolute path in"
    echo "                          UNIX or DOS notation (starting with a slash or a drive letter)'"
    echo "UNISONUMASK            = '0[0-7][0-7][0-7]?'"
    echo "                       : 'not a valid umask! This should be an octal constant starting"
    echo "                          with the number 0. It should be at least three numbers long.'"
    echo ""
    ) > /etc/check.d/${packages_name}.exp

    # Set rights for check.exp file
    chmod 0644 /etc/check.d/${packages_name}.exp
    chown root /etc/check.d/${packages_name}.exp
}


# -----------------------------------------------------------------------------
# Main
# -----------------------------------------------------------------------------
# write default config file
make_config_file /etc/default.d/$packages_name

# update from old version
rename_old_variables
add_new_variables

# write new config file
make_config_file /etc/config.d/$packages_name

# write check.d file
make_check_file

# -----------------------------------------------------------------------------

