#!/bin/sh
#------------------------------------------------------------------------------
# /var/install/config.d/unison.sh - configuration generator script for UNISON
#
# Copyright (c) 2004 Daniel Vogel <daniel_vogel(at)t-online(dot)de>
#
# Creation:     03.07.2005 dv
# Last Update:  $Id: unison.sh 2 2017-10-18 18:52:17Z  $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

. /var/install/include/eislib
. /etc/config.d/unison

# check command line
quiet="no"
if [ "${1}" = "--quiet" ]
then
    quiet="yes"
fi

# setup crontab path   
crontab_path=/var/cron/etc/root
crontab_file=${crontab_path}/unison


#------------------------------------------------------------------------------
# Write Profiles
#------------------------------------------------------------------------------

write_profiles ()
{
    if [ "${quiet}" = "no" ]
    then
        mecho -info "Writing profiles..."
    fi

    idx=1
    while [ "$idx" -le "$UNISON_DIR_N" ]
    do
        profile_file="/var/lib/unison/replica$idx.prf"

        eval netsync='$UNISON_DIR_'$idx'_NETSYNC'
        eval host='$UNISON_DIR_'$idx'_HOST'
        eval usessh='$UNISON_DIR_'$idx'_USESSH'
        eval usesocket='$UNISON_DIR_'$idx'_USESOCKET'
        eval sockport='$UNISON_DIR_'$idx'_SOCKPORT'
        eval sshuser='$UNISON_DIR_'$idx'_SSHUSER'
        eval sshport='$UNISON_DIR_'$idx'_SSHPORT'
        eval sshcompress='$UNISON_DIR_'$idx'_SSHCOMPRESS'

        eval localdir='$UNISON_DIR_'$idx'_LOCAL'
        eval remotedir='$UNISON_DIR_'$idx'_REMOTE'
        eval force='$UNISON_DIR_'$idx'_FORCE'
        eval stimes='$UNISON_DIR_'$idx'_TIMES'
        eval sgroup='$UNISON_DIR_'$idx'_GROUP'
        eval sowner='$UNISON_DIR_'$idx'_OWNER'
        eval snumeric='$UNISON_DIR_'$idx'_NUMIDS'
        eval sfat='$UNISON_DIR_'$idx'_FAT'

        eval numpaths='$UNISON_DIR_'$idx'_PATH_N'
        eval numexcfiles='$UNISON_DIR_'$idx'_EXC_FILE_N'
        eval numexcpaths='$UNISON_DIR_'$idx'_EXC_PATH_N'
        eval numincfiles='$UNISON_DIR_'$idx'_INC_FILE_N'
        eval numincpaths='$UNISON_DIR_'$idx'_INC_PATH_N'

        if [ "$netsync" == "yes" ]
        then
            if [ "$usessh" == "yes" -a "$usesocket" == "yes" ]
            then
                mecho -warn "SSH-method and SOCKET-method are configured both!"
                mecho -warn "Using SSH-method for replica $idx!"
            fi
            if [ "$usessh" == "no" -a "$usesocket" == "no" ]
            then
                mecho -warn "Neither SSH-method nor SOCKET-method are configured!"
                mecho -warn "Using standard SOCKET method for replica $idx!"
            fi
        fi

        # write file
        {
            echo "#"
            echo "# Do not edit this file directly, edit unison configuration"
            echo "# using eisfair configuration tools"
            echo "# Creation date: `date`"


            echo ""
            echo "# Roots of the synchronisation "
            if [ "$netsync" == "yes" ]
            then
                if [ "$usessh" == "yes" ]
                then
                    echo "root = $localdir"
                    echo "root = ssh://$sshuser@$host/$remotedir"

                    if [ "$sshcompress" == "yes" ]
                    then
                        echo "sshargs = -p $sshport -C"
                    else
                        echo "sshargs = -p $sshport"
                    fi

                    if [ "$force" == "remote" ]
                    then
                        echo "force = ssh://$sshuser@$host/$remotedir"
                    fi
                else 
                    if [ "$usesocket" == "yes" ]
                    then
                        echo "root = $localdir"
                        echo "root = socket://$host:$sockport/$remotedir"

                        if [ "$force" == "remote" ]
                        then
                            echo "force = socket://$host:$sockport/$remotedir"
                        fi
                    else
                        echo "root = $localdir"
                        echo "root = socket://$host:3000/$remotedir"

                        if [ "$force" == "remote" ]
                        then
                            echo "force = socket://$host:3000/$remotedir"
                        fi
                    fi
                fi
            else
                echo "root = $localdir"
                echo "root = $remotedir"

                if [ "$force" == "remote" ]
                then
                    echo "force = $remotedir"
                fi
            fi
            if [ "$force" == "local" ]
            then
                echo "force = $localdir"
            fi
            
            iidx=1
            if [ "$iidx" -le "$numpaths" ]
            then
                echo ""
                echo "# Subdirectories to synchronize"
                while [ "$iidx" -le "$numpaths" ]
                do
                    eval syncpath='$UNISON_DIR_'$idx'_PATH_'$iidx
                    echo "path = $syncpath"
                    iidx=`/usr/bin/expr $iidx + 1`
                done
            fi

            iidx=1
            if [ "$iidx" -le "$numexcfiles" ]
            then
                echo ""
                echo "# Files to exclude"
                while [ "$iidx" -le "$numexcfiles" ]
                do
                    eval ignfile='$UNISON_DIR_'$idx'_EXC_FILE_'$iidx
                    echo "ignore = Name $ignfile"
                    iidx=`/usr/bin/expr $iidx + 1`
                done
            fi

            iidx=1
            if [ "$iidx" -le "$numexcpaths" ]
            then
                echo ""
                echo "# Paths to exclude"
                while [ "$iidx" -le "$numexcpaths" ]
                do
                    eval ignpath='$UNISON_DIR_'$idx'_EXC_PATH_'$iidx
                    echo "ignore = Path $ignpath"
                    iidx=`/usr/bin/expr $iidx + 1`
                done
            fi

            iidx=1
            if [ "$iidx" -le "$numincfiles" ]
            then
                echo ""
                echo "# Files to reinclude"
                while [ "$iidx" -le "$numincfiles" ]
                do
                    eval incfile='$UNISON_DIR_'$idx'_INC_FILE_'$iidx
                    echo "ignorenot = Name $incfile"
                    iidx=`/usr/bin/expr $iidx + 1`
                done
            fi

            echo ""
            echo "# Other flags"
            if [ "$stimes" == "yes" ]
            then
               echo "times = true"
            fi
            if [ "$sgroup" == "yes" ]
            then
               echo "group = true"
            fi
            if [ "$sowner" == "yes" ]
            then
               echo "owner = true"
            fi
            if [ "$snumeric" == "yes" ]
            then
               echo "numericids = true"
            fi

            if [ "$sfat" == "yes" ]
            then
               echo "fat = true"
            fi

        } > $profile_file

        idx=`/usr/bin/expr $idx + 1`
    done
}


#------------------------------------------------------------------------------
# Add and delete cron jobs for automatic update
#------------------------------------------------------------------------------

add_cron_jobs ()
{
    PROG=/var/install/bin/unison-tools-manual

    if [ "${quiet}" = "no" ]
    then
        mecho -info "Creating cron jobs..."
    fi

    # check for cron directory
    if [ ! -d $crontab_path ]
    then
        mkdir -p $crontab_path
    fi

    # first of all: delete existing cron file
    if [ -f $crontab_file ]
    then
        rm -f $crontab_file
    fi

    # now check, if there is anything else to do
    idx=1
    enable_cron="no"
    while [ "$idx" -le "$UNISON_DIR_N" ]
    do
       eval automode='$UNISON_DIR_'$idx'_AUTO'

       if [ "$automode" == "yes" ]
       then
          enable_cron="yes"
       fi
       idx=`/usr/bin/expr $idx + 1`
    done

    # if there are active jobs, rewrite the crontab file
    if [ "$enable_cron" == "yes" ]
    then
        # write file
        {
            echo "#"
            echo "# Do not edit this file, edit unison configuration"
            echo "# using eisfair configuration tools"
            echo "# Creation date: `date`"

            idx=1
            while [ "$idx" -le "$UNISON_DIR_N" ]
            do
                eval automode='$UNISON_DIR_'$idx'_AUTO'

                if [ "$automode" == "yes" ]
                then
                    eval schedule='$UNISON_DIR_'$idx'_SCHEDULE'
                    echo "$schedule $PROG $idx"
                fi
                idx=`/usr/bin/expr $idx + 1`
            done
        } > $crontab_file
    fi

    # update crontab file
    /var/install/config.d/cron > /dev/null 2> /dev/null
}

#------------------------------------------------------------------------------
# Create logrotate config file
#------------------------------------------------------------------------------

create_logrotate ()
{
    if [ "${quiet}" = "no" ]
    then
        mecho -info "Creating logrotate file ..."
    fi

    {
        echo "#------------------------------------------------------------------"
        echo "# unison configuration file for logrotate"
        echo "#"
        echo "# Do not edit this file"
        echo "# Creation date: $(date)"
        echo "#------------------------------------------------------------------"
        echo ""
        echo "/var/log/unison.log {"
        echo "    rotate 10"
        echo "    weekly"
        echo "    compress"
        echo "    missingok"
        echo "    notifempty"
        echo "    }"
        echo ""
    } > /etc/logrotate.d/unison
}


#------------------------------------------------------------------------------
# Main
#------------------------------------------------------------------------------

# write profile files
write_profiles

# add cron jobs
add_cron_jobs

# create logrotate file
create_logrotate

# create/remove start link
if [ "$START_UNISON" = "yes" ]
then
    ln -sf /etc/init.d/unison /etc/rc2.d/S65unison
else
    if [ -f /etc/rc2.d/S65unison ]
    then
        rm -f /etc/rc2.d/S65unison
    fi
fi

#------------------------------------------------------------------------------
# End
#------------------------------------------------------------------------------
exit 0
